==> viha-5.15.tar.gz: viha-5.15/paivystys.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paivystys";
$file = "paivystys.php";

include "common.php";
include "paivystys-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaatiot</title>
</head>
" . body_bgcolor() . "
<h1>Operaatioihin liittyvien tietojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$nimi = get_txt('nimi');
$oletus_verkko_id = get_nro_1('oletus_verkko_id');
$johto_ryhma_id = get_nro_1('johto_ryhma_id');
$viesti_ryhma_id = get_nro_1('viesti_ryhma_id');
$tuki_ids = get_multi_nro('tuki_ids');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_aluevastaava($file);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = paivystys_add_ok($herja,$alue_id,$nimi,$oletus_verkko_id,
			  $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = $alue_id,
           nimi = '$nimi',
           oletus_verkko_id = $oletus_verkko_id,
           johto_ryhma_id = $johto_ryhma_id,
           viesti_ryhma_id = $viesti_ryhma_id,
           ts = '$now'";
    my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    $new_id = last_insert_id();
    loki("$sql id=$new_id");
    # meaningless?
    # set_tuki_ids($now,$new_id,$tuki_ids);
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paivystys_save_ok($herja,$id,$alue_id,$nimi,$oletus_verkko_id,
			   $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = $alue_id,
           nimi='$nimi',
           oletus_verkko_id=$oletus_verkko_id,
           johto_ryhma_id = $johto_ryhma_id,
           viesti_ryhma_id = $viesti_ryhma_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    set_tuki_ids($now,$id,$tuki_ids);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = paivystys_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql,true,true);
    $sql = "DELETE FROM paivystys_tuki WHERE paivystys_id = $id";
    my_mysql_query ($sql,true,true);
    loki($sql);
    # silently update the man-hour table as well
    $sql =
      "UPDATE hlo_ajat
       SET variable_id = 1
       WHERE variable_id = $id
             AND (hlo_ajat_tyyppi_id = 4 OR hlo_ajat_tyyppi_id < 3)";
    my_mysql_query ($sql,true,true);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $alue_id = "1";
    $nimi = '';
    $oletus_verkko_id = "1";
    $johto_ryhma_id = "1";
    $viesti_ryhma_id = "1";
    $tuki_ids = array();
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = paivystys_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";

echo "<h2>Operaatioiden pivitys, lisys ja poisto</h2>\n";

echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id']; 
  $nimi = $a['nimi']; 
  $oletus_verkko_id = $a['oletus_verkko_id'];
  $johto_ryhma_id = $a['johto_ryhma_id'];
  $viesti_ryhma_id = $a['viesti_ryhma_id'];
  $tuki_ids = fetch_tuki_ids($id);
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Nimi:";
if ($readonly) {
  echo "<td>$nimi\n";
} else {
  echo "<td><input type=\"text\" name=\"nimi\" size=64 maxlength=255";
  echo " value=\"$nimi\">\n";
}

echo "<tr><td>Oletusradioverkko:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT verkko FROM verkko WHERE id = $oletus_verkko_id")
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("oletus_verkko_id", $oletus_verkko_id, "verkko", "id",
	      "verkko", "ORDER BY verkko");
}

echo "<tr><td>Operaation johtoryhm:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("ryhma","kutsu",$johto_ryhma_id)
    . "\n";
} else {
  echo "<td>\n";
  select_johto_ryhma($johto_ryhma_id,$id);
}

echo "<tr><td>Operaation viestiasema:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("ryhma","kutsu",$viesti_ryhma_id)
    . "\n";
} else {
  echo "<td>\n";
  select_viesti_ryhma($viesti_ryhma_id,$id);
}

echo "<tr><td>Operaation aputukiasemat:";
if ($readonly) {
  echo "<td>\n";
  list_tuki_ids($tuki_ids);
 }  else {
  echo "<td>\n";
  select_tuki_ids($id);
 }

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.nimi, $table.alue_id, alue.alue, verkko,
       johto_ryhma_id, viesti_ryhma_id
FROM $table, verkko, alue
WHERE verkko.id = oletus_verkko_id AND alue.id = $table.alue_id
ORDER BY alue, paivystys.nimi
";
$result = my_mysql_query($sql);
if ($result) {
    echo "<p><TABLE BORDER=1>\n";
    echo tr_bgcolor()
      . "<TH>Id<TH>Aikaleima<TH>Alue<TH>Nimi<TH>Oletusverkko"
      . "<TH>Jory<TH>Viesti<TH>Tuet\n";
    while ($a = mysql_fetch_array($result)) {
      # just skip those rows we do not have permission to
      if (alue_oikeus($a['alue_id']) == 2)
	continue;
      echo "<TR><TD>$a[id]",
	"<TD>$a[ts]",
	"<TD>$a[alue]",
	"<TD>$a[nimi]",
	"<TD>$a[verkko]",
	"<TD>" . tab_col_id_x_not("ryhma","kutsu",$a['johto_ryhma_id'],1),
	"<TD>" . tab_col_id_x_not("ryhma","kutsu",$a['viesti_ryhma_id'],1),
	"<td>" . ota_yksi("SELECT COUNT(*)
                           FROM paivystys_tuki
                           WHERE paivystys_id = $a[id]");
      if (($id == "0") && ($a['id'] > 2)) {
	echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
    echo "</TABLE>";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paivystys.php,v 1.25 2009/06/06 14:21:57 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/paivystys.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paivystys";
$file = "paivystys.php";

include "common.php";
include "paivystys-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaatiot</title>
</head>
" . body_bgcolor() . "
<h1>Operaatioihin liittyvien tietojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_0('alue_id');
if ($alue_id == 0)
  $alue_id = s('alue');
$nimi = get_txt('nimi');
$oletus_verkko_id = get_nro_1('oletus_verkko_id');
$johto_ryhma_id = get_nro_1('johto_ryhma_id');
$viesti_ryhma_id = get_nro_1('viesti_ryhma_id');
$tuki_ids = get_multi_nro('tuki_ids');
$alkoi = get_txt('alkoi');
$alkoi = maaginen_kello($alkoi);

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_aluevastaava($file);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = paivystys_add_ok($herja,$alue_id,$nimi,$oletus_verkko_id,
			  $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,$alkoi);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = $alue_id,
           nimi = '$nimi',
           oletus_verkko_id = $oletus_verkko_id,
           johto_ryhma_id = $johto_ryhma_id,
           viesti_ryhma_id = $viesti_ryhma_id,
           alkoi = '$now',
           ts = '$now'";
    my_mysql_query ($sql);
    $clear = "ADD";
    $new_id = last_insert_id();
    loki("$sql id=$new_id");
    # meaningless?
    # set_tuki_ids($now,$new_id,$tuki_ids);
    # valitaan saman tien. loogisempaa.
    $_SESSION[$prefix . 'paivystys'] = $new_id;
    $_SESSION[$prefix . 'alue'] =
      tab_col_id("paivystys","alue_id",$new_id);
    tehty("Listty ja valittu operaatio " . muotoile_operaatio($new_id));
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paivystys_save_ok($herja,$id,$alue_id,$nimi,$oletus_verkko_id,
			   $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,$alkoi);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = $alue_id,
           nimi='$nimi',
           oletus_verkko_id=$oletus_verkko_id,
           johto_ryhma_id = $johto_ryhma_id,
           viesti_ryhma_id = $viesti_ryhma_id,
           alkoi = '$alkoi',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    tehty( "Pivitetty operaatiota " . muotoile_operaatio($id));
    loki($sql);
    set_tuki_ids($now,$id,$tuki_ids);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = paivystys_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $tmp_nimi = muotoile_operaatio($id);
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql,true,true);
    $sql = "DELETE FROM paivystys_tuki WHERE paivystys_id = $id";
    my_mysql_query ($sql,true,true);
    # silently update the man-hour atd log tables as well
    $sql =
      "UPDATE hlo_ajat
       SET variable_id = 1
       WHERE variable_id = $id
             AND (hlo_ajat_tyyppi_id = 4 OR hlo_ajat_tyyppi_id < 3)";
    my_mysql_query ($sql,true,true);
    $sql = "UPDATE loki SET paivystys_id = 1 WHERE paivystys_id = $id";
    my_mysql_query ($sql);
    tehty("Poistettu operaatio $tmp_nimi");
    $clear = "CONFIRM";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $alue_id = s('alue');
    $nimi = '';
    $oletus_verkko_id = "1";
    $johto_ryhma_id = "1";
    $viesti_ryhma_id = "1";
    $tuki_ids = array();
    $alkoi = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = paivystys_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";

echo "<h2>Operaatioiden pivitys, lisys ja poisto</h2>\n";

echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id']; 
  $nimi = $a['nimi']; 
  $oletus_verkko_id = $a['oletus_verkko_id'];
  $johto_ryhma_id = $a['johto_ryhma_id'];
  $viesti_ryhma_id = $a['viesti_ryhma_id'];
  $tuki_ids = fetch_tuki_ids($id);
  $alkoi = $a['alkoi'];
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Nimi:";
if ($readonly) {
  echo "<td>$nimi\n";
} else {
  echo "<td><input type=\"text\" name=\"nimi\" size=64 maxlength=255";
  echo " value=\"$nimi\">\n";
}

echo "<tr><td>Oletusradioverkko:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT verkko FROM verkko WHERE id = $oletus_verkko_id")
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("oletus_verkko_id", $oletus_verkko_id, "verkko", "id",
	      "verkko", "ORDER BY verkko");
}

echo "<tr><td>Operaation johtoryhm:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("ryhma","kutsu",$johto_ryhma_id)
    . "\n";
} else {
  echo "<td>\n";
  select_johto_ryhma($johto_ryhma_id,$id);
}

echo "<tr><td>Operaation viestiasema:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("ryhma","kutsu",$viesti_ryhma_id)
    . "\n";
} else {
  echo "<td>\n";
  select_viesti_ryhma($viesti_ryhma_id,$id);
}

echo "<tr><td>Operaation aputukiasemat:";
if ($readonly) {
  echo "<td>\n";
  list_tuki_ids($tuki_ids);
 }  else {
  echo "<td>\n";
  select_tuki_ids($id);
 }

echo "<tr><td>Operaatio alkoi:<td>";
if ($readonly) { echo "$alkoi\n"; } else {
  echo "<input type=\"text\" name=\"alkoi\" size=19 maxlength=19";
  echo " value=\"$alkoi\">
Koska operaatio on aloitettu. HH:MM tai X tai -MM tai +MM.\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.nimi, $table.alue_id, alue.alue, verkko,
       johto_ryhma_id, viesti_ryhma_id, alkoi
FROM $table, verkko, alue
WHERE verkko.id = oletus_verkko_id AND alue.id = $table.alue_id
ORDER BY alue, paivystys.nimi
";
$result = my_mysql_query($sql);
if ($result) {
    echo "<p><TABLE BORDER=1>\n";
    tr_reset();
    echo tr_vaalsin()
      . "<TH>Id<TH>Aikaleima<TH>Alkoi<TH>Alue<TH>Nimi<TH>Verkko"
      . "<TH>Jory<TH>Viesti<TH>Tuet\n";
    while ($a = mysql_fetch_array($result)) {
      # just skip those rows we do not have permission to
      if (alue_oikeus($a['alue_id']) == 2)
	continue;
      echo tr() . "<TD>$a[id]",
	"<TD>$a[ts]",
	"<TD>$a[alkoi]",
	"<TD>$a[alue]",
	"<TD>$a[nimi]",
	"<TD>$a[verkko]",
	"<TD>" . tab_col_id_x_not("ryhma","kutsu",$a['johto_ryhma_id'],1),
	"<TD>" . tab_col_id_x_not("ryhma","kutsu",$a['viesti_ryhma_id'],1),
	"<td>" . ota_yksi("SELECT COUNT(*)
                           FROM paivystys_tuki
                           WHERE paivystys_id = $a[id]");
      if (($id == "0") && ($a['id'] > 2)) {
	echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
    echo "</TABLE>";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paivystys.php,v 1.31 2009/10/05 16:07:07 riku Exp $ -->
